@@ -461,7 +461,7 @@ class InfEngineServer:
                 dlsources, self.root_path / INF_ENGINE_COMPILER_CONFIG, dldata, strict
             )
 
-        engine.install(dldata, dlsources)
+        engine.install(dldata, dlsources, db_name=db_name)
 
         self.restart()
 
